import { api } from '@/services/api';
import { request } from '@umijs/max';
type Page = {
    pageSize: number | string,
    pageNum: number | string
}
interface PublicParams{
    miniappId: string,//微信小程序组件ID
    distributorId: string,//分销商ID
    appType: string,//小程序类型 1:微信小程序、2：抖音小程序
}
export interface Params extends Page,PublicParams{}
/**书币充值模板列表 */
export async function appRechargeTemplateList(params: Params) {
    return request(api + '/admin/appCoinRechargeTemplate/list', {
        method: 'GET',
        params
    });
}
/**书币充值模板详情 */
export async function appRechargeTemplateInfo(id: string) {
    return request(api + `/admin/appCoinRechargeTemplate/getInfo/${id}`, {
        method: 'GET',
    });
}
/**书币充值模板删除 */
export async function appRechargeTemplateRemove(id: string) {
    return request(api + `/admin/appCoinRechargeTemplate/remove/${id}`, {
        method: 'DELETE',
    });
}
interface RechargeConfig {
    price: string,//价格
    gift: string,//赠送
    extra: string,//额外赠送
    description: string,//额外描述
}
interface Data extends PublicParams {
    id?: string,//编辑时的ID
    templateName: string,//模板名称
    templateDescription: string,//充值模板描述
    rechargeConfigJson: RechargeConfig,//充值挡位配置
    activateTemplate: boolean,//当前激活的充值模板;true :已激活 false :未激活
    remark?: string,//备注
}
/**书币充值模板新增*/
export async function appRechargeTemplateSave(data: Data) {
    return request(api + `/admin/appCoinRechargeTemplate/save`, {
        method: 'POST',
        data
    });
}
/**书币充值模板修改*/
export async function appRechargeTemplateUpdate(params: Data) {
    let { id, ...data } = params
    return request(api + `/admin/appCoinRechargeTemplate/update/${id}`, {
        method: 'PUT',
        data
    });
}
interface DataSwitch extends PublicParams{
    id:string,//模板ID
}
/**书币充值模板修改*/
export async function appRechargeTemplateSwitch(data: DataSwitch) {
    return request(api + `/admin/appCoinRechargeTemplate/updateTemplate`, {
        method: 'PUT',
        data
    });
}















/**===========================================Vip充值模板列表 ===========================================*/
export async function appVipRechargeTemplateList(params: Params) {
    return request(api + '/admin/appVipRechargeTemplate/list', {
        method: 'GET',
        params
    });
}
/**Vip充值模板详情 */
export async function appVipRechargeTemplateInfo(id: string) {
    return request(api + `/admin/appVipRechargeTemplate/getInfo/${id}`, {
        method: 'GET',
    });
}
/**Vip充值模板删除 */
export async function appVipRechargeTemplateRemove(id: string) {
    return request(api + `/admin/appVipRechargeTemplate/remove/${id}`, {
        method: 'DELETE',
    });
}
interface RechargeConfig {
    price: string,//价格
    gift: string,//赠送
    extra: string,//额外赠送
    description: string,//额外描述
}
interface Data extends PublicParams {
    id?: string,//编辑时的ID
    templateName: string,//模板名称
    templateDescription: string,//充值模板描述
    rechargeConfigJson: RechargeConfig,//充值挡位配置
    activateTemplate: boolean,//当前激活的充值模板;true :已激活 false :未激活
    remark?: string,//备注
}
/**Vip充值模板新增*/
export async function appVipRechargeTemplateSave(data: Data) {
    return request(api + `/admin/appVipRechargeTemplate/save`, {
        method: 'POST',
        data
    });
}
/**Vip充值模板修改*/
export async function appVipRechargeTemplateUpdate(params: Data) {
    let { id, ...data } = params
    return request(api + `/admin/appVipRechargeTemplate/update/${id}`, {
        method: 'PUT',
        data
    });
}
interface DataSwitch extends PublicParams{
    id:string,//模板ID
}
/**Vip充值模板修改*/
export async function appVipRechargeTemplateSwitch(data: DataSwitch) {
    return request(api + `/admin/appVipRechargeTemplate/updateTemplate`, {
        method: 'PUT',
        data
    });
}
